@@ -1,6 +1,6 @@
 package Data::SearchEngine::ElasticSearch;
 {
-  $Data::SearchEngine::ElasticSearch::VERSION = '0.11';
+  $Data::SearchEngine::ElasticSearch::VERSION = '0.12';
 }
 use Moose;
 
@@ -55,13 +55,19 @@ sub add {
     my @docs;
     foreach my $item (@{ $items }) {
 
-        my $data = $item->values;
-        push(@docs, {
-            index => delete($data->{index}),
-            type => delete($data->{type}),
+        my %data = %{ $item->values };
+
+        my %doc = (
+            index => delete($data{index}),
+            type => delete($data{type}),
             id => $item->id,
-            data => $data
-        })
+            data => \%data
+        );
+        # Check for a version
+        if(exists($data{'_version'})) {
+            $doc{version} = delete($data{'_version'});
+        }
+        push(@docs, \%doc);
     }
     $self->_es->bulk_index(\@docs);
 }
@@ -219,15 +225,36 @@ sub search {
         my $values = $doc->{_source};
         $values->{_index} = $doc->{_index};
         $values->{_version} = $doc->{_version};
-        $result->add(Data::SearchEngine::Item->new(
-            id      => $doc->{_id},
-            values  => $values,
-        ));
+        $result->add($self->_doc_to_item($doc));
     }
 
     return $result;
 }
 
+sub _doc_to_item {
+    my ($self, $doc) = @_;
+
+    my $values = $doc->{_source};
+    $values->{_index} = $doc->{_index};
+    $values->{_version} = $doc->{_version};
+    return Data::SearchEngine::Item->new(
+        id      => $doc->{_id},
+        values  => $values,
+    );
+}
+
+sub find_by_id {
+    my ($self, $index, $type, $id) = @_;
+
+    my $doc = $self->_es->get(
+        index => $index,
+        type => $type,
+        id => $id
+    );
+
+    return $self->_doc_to_item($doc);
+}
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
@@ -242,7 +269,7 @@ Data::SearchEngine::ElasticSearch - ElasticSearch support for Data::SearchEngine
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -384,6 +411,10 @@ Remove the specified item from the index.  Uses the item's C<id>.
 
 Search!
 
+=head2 find_by_id ($index, $type, $id)
+
+Find a document by it's unique id.
+
 =head1 AUTHOR
 
 Cory G Watson <gphat@cpan.org>
